#
# spec file for package perl-Text-CSV_XS
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Text-CSV_XS
Name:           perl-Text-CSV_XS
Version:        1.590.0
Release:        1.1
# 1.59 -> normalize -> 1.590.0
%define cpan_version 1.59
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Comma-Separated Values manipulation routines
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/H/HM/HMBRAND/%{cpan_name}-%{cpan_version}.tgz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
Provides:       perl(Text::CSV_XS) = %{version}
%undefine       __perllib_provides
Recommends:     perl(Encode) >= 3.21
%{perl_requires}

%description
Text::CSV_XS provides facilities for the composition and decomposition of
comma-separated values. An instance of the Text::CSV_XS class will combine
fields into a 'CSV' string and parse a 'CSV' string into fields.

The module accepts either strings or files as input and support the use of
user-specified characters for delimiters, separators, and escapes.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644
# MANUAL BEGIN
sed -i -e 's,/pro/bin/perl,/usr/bin/perl,' examples/*
# MANUAL END

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc ChangeLog CONTRIBUTING.md examples README

%changelog
* Mon Jan  6 2025 Tina Müller <timueller+perl@suse.de>
- updated to 1.590.0 (1.59)
  see /usr/share/doc/packages/perl-Text-CSV_XS/ChangeLog
  1.59	- 2025-01-05, H.Merijn Brand
  * Fixed EOL test for Windows with crnl layer
  * It is 2025
  1.58	- 2024-12-30, H.Merijn Brand
  * Add strict_eol (warnings default in csv ())
  * Add XS line number in errors
  * Add streaming support - not set in stone
  1.57	- 2024-11-12, H.Merijn Brand
  * Keep runtime error from csv ()
  * add csv (on_error)
* Sat Aug 10 2024 Tina Müller <timueller+perl@suse.de>
- updated to 1.560.0 (1.56)
  see /usr/share/doc/packages/perl-Text-CSV_XS/ChangeLog
  1.56	- 2024-08-09, H.Merijn Brand
  * Yet another strict/comment_str conflict (issue 57)
  * Strict affected by column_names
* Sun Jun 23 2024 Tina Müller <tina.mueller@suse.com>
- updated to 1.550.0 (1.55)
  see /usr/share/doc/packages/perl-Text-CSV_XS/ChangeLog
  1.55	- 2024-06-18, H.Merijn Brand
  * More fixes for strict under bind_columns (issue 54)
  * Strict won't hide previous error (issue 56)
* Fri Apr 19 2024 Tina Müller <timueller+perl@suse.de>
- updated to 1.54
  see /usr/share/doc/packages/perl-Text-CSV_XS/ChangeLog
  1.54	- 2024-04-18, H.Merijn Brand
  * Fix doc (Jean Forget, RT#150757)
  * It's 2024
  * Fix comment_str with strict
  * Doc fixup (RT#151546)
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Fri Nov 24 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.53
  see /usr/share/doc/packages/perl-Text-CSV_XS/ChangeLog
  1.53	- 2023-11-22, H.Merijn Brand
  * Two casts for -Wformat (issue 50)
  * Add --skip-empty to csv2xlsx
  * Add --font and --font-size to csv2xlsx
  * Fix skip_empty_rows ("skip") and trailing newlines (Corey Hickey, PR#52)
  * Fix comment in last line (RT#150501)
* Fri Sep 22 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.52
  see /usr/share/doc/packages/perl-Text-CSV_XS/ChangeLog
  1.52	- 2023-09-21, H.Merijn Brand
  * Fix possible coredump in cache on non-IO parse (issue 49)
* Tue Aug  8 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.51
  see /usr/share/doc/packages/perl-Text-CSV_XS/ChangeLog
  1.51	- 2023-08-07, H.Merijn Brand
  * Contact e-mail update
  * Attribute skip_empty_rows extended
  * Fix comments (PR#45)
  * Fix help (x12340, PR#46)
  * Update to Devel::PPPort-3.71
  * Fix HTML on Windows
  * Fix double header-interpretation on bom + headers => "auto" (issue 47)
* Thu Mar  2 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.50
  see /usr/share/doc/packages/perl-Text-CSV_XS/ChangeLog
  1.50	- 2023-03-01, H.Merijn Brand
  * Promote sep to sep_set in csv () with auto-headers
  * Fix bug in set_diag surfaced by PERL_RC_STACK
* Wed Jan  4 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.49
  see /usr/share/doc/packages/perl-Text-CSV_XS/ChangeLog
  1.49	- 2023-01-03, H.Merijn Brand
  * csv2xlsx --split=CxP [--split-label=C]
  * Full documentation/manual for csv2xlsx
  * Fix non-integer arguments to getline_all (issue 39)
  * It's 2023
* Thu May 26 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.48
  see /usr/share/doc/packages/perl-Text-CSV_XS/ChangeLog
  1.48	- 2022-05-24, H.Merijn Brand
  * It's 2022
  * Update to Devel::PPPort-3.64
  * kh => 1 (use internal headers)
  * Update to Devel::PPPort-3.67
  * Add constants for META flags (RT#142508)
  * Update to Devel::PPPort-3.68
  * Export :CONSTANTS
  * Fix sep_set typo (issue 37)
  * Tested against perl-5.36.0
* Wed Dec 22 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.47
  see /usr/share/doc/packages/perl-Text-CSV_XS/ChangeLog
  1.47	- 2021-12-21, H.Merijn Brand
  * Make error 2014 catchable
  * Suppress empty lines on empty input (issue 34)
  * Perl 6 -> Raku in docs (RT#136864)
  * IETF changed their URLs
  * Add some documentation for Google hist (Nigel)
* Thu Mar 25 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.46
  see /usr/share/doc/packages/perl-Text-CSV_XS/ChangeLog
  1.46	- 2021-03-24, H.Merijn Brand
  * It's 2021
  * New attribute comment_str     (RFC 4180-bis)
  * New attribute skip_empty_rows (RFC 4180-bis)
  * http -> https in links in docs
  * Fix several issues with auto-detecting \r as EOL
  * Tested on perl-5.6.1 .. perl-5.32.1 and perl-5.33.8 (145)
* Fri Dec 25 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.45
  see /usr/share/doc/packages/perl-Text-CSV_XS/ChangeLog
  1.45	- 2020-12-24, H.Merijn Brand
  * Update to Devel::PPPort-3.60 (3.59 was b0rked)
  * Allow adding to existing data in csv (out => $ref)
  * examples/csv2xlsx : -L   # to limit records to export
  * examples/csv2xlsx : --de # for possible double-encoding fix
  * Update to Devel::PPPort-3.61
  * Update to Devel::PPPort-3.62
  * Add examples/csv-split
  * examples/csv2xlsx : Check if .xlsx is creatable before conversion
  * Small doc additions
  * Fix META issue for bugtracker
* Wed Jul 29 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.44
  see /usr/share/doc/packages/perl-Text-CSV_XS/ChangeLog
  1.44	- 2020-07-22, H.Merijn Brand
  * EBCDIC now fully functional
  * Prevent false negative CPANTESTERS fail reports
  * Fully tested on perl-5.32.0 and perl-5.33.0
  * Fix partly decoded fields in header (found by Eric Brine)
* Thu May 28 2020 Tina Müller <timueller+perl@suse.de>
  updated to 1.43
  see /usr/share/doc/packages/perl-Text-CSV_XS/ChangeLog
  1.43	- 2020-05-27, H.Merijn Brand
  * Add --parser-opt[=value] to csv-check
  * Add -L & -X to csv-check
  * Fix undef value in attribute setters for strings (issue 24)
  * Document quote (undef) is not supported
* Wed May 20 2020 Tina Müller <timueller+perl@suse.de>
  updated to 1.42
  see /usr/share/doc/packages/perl-Text-CSV_XS/ChangeLog
  1.42	- 2020-05-19, H.Merijn Brand
  * Update to Devel::PPPort-3.58
  * Unicode fixes for csv2xls and csv2xlsx
  * Add internal buffers to cache diagnostics
  * Fix positional reporting in examples/csv-check
  * Allow passing CSV parsing attributes to csv-check
  * Proof reading - doc fixes by Klaus Baldermann <soonix> (PR#21)
  * Fix type caching (RT#132344)
  * Small doc fix by Nick Tonkin <1nickt> (PR#22)
  * Fix sep=; being ignored in ->header (issue 23)
* Mon Feb 17 2020 <timueller+perl@suse.de>
- updated to 1.41
  see /usr/share/doc/packages/perl-Text-CSV_XS/ChangeLog
  1.41	- 2020-02-16, H.Merijn Brand
  * Update to Devel::PPPort-3.56
  * csv2xls uses sheetname as csv2xlsx
  * csv2xlsx: support images (each image gets its own tab)
  * More docs. (Data validation)
  * It's 2020
  * No binary literals in fixed error messages
  * Fix auto_diag > 2 to die when headers are used (issue 19)
* Mon Sep 16 2019 <timueller+perl@suse.de>
- updated to 1.40
  see /usr/share/doc/packages/perl-Text-CSV_XS/ChangeLog
  1.40	- 2019-09-15, H.Merijn Brand
  * Update to Devel::PPPort-3.52
  * Development perl is now 5.28.2
  * [csv2xlsx] sheetnames are restricted to 31 characters
  * Generate cpanfile
  * Add munge type "db"
  * [csv2xls/csv2xlsx] do not generate xls/xlsx on empty CSV (issue#18)
  * New: support $csv->formula (sub { ... })
  * Support stacked encodings
* Mon Mar 18 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- update to 1.39
  1.39 - 2019-03-15, H.Merijn Brand
  * It's 2019
  * Fix tests to skip on Encode failing (PR#17 charsbar + klapperl)
  * Tested on Z/OS (s390x - Hercules) :)
  * Test with new Module::CPANTS::Analyse
  * Add options -w/-b/-Z to csvdiff
  * Fix strict on streaming EOF
  * Now also tested with cperl
  1.38 - 2018-12-30, H.Merijn Brand
  * Name the duplicate headers on error 1013
  * Add missing attributes to default list (doc only, David H. Gutteridge)
  * Add support for combined keys
  * Look at $NO_COLOR for csvdiff
  * Add support for key-value pair
* Sat Sep 29 2018 Dirk Stoecker <opensuse@dstoecker.de>
- update to 1.37
  1.37 - 2018-09-27, H.Merijn Brand
  * Moved pod-tests from t to xt
  * Add munge as alias for munge_column_names
  * Update Devel::PPPort
  * Simplified ref-check defines in XS (issue 12, thanks pali)
  * Tested against perl-5.29.3
* Mon Jul 16 2018 coolo@suse.com
- updated to 1.36
  see /usr/share/doc/packages/perl-Text-CSV_XS/ChangeLog
  1.36	- 2018-06-26, H.Merijn Brand
  * Now also tested on FreeBSD-11.1
  * Update to Devel::PPPort-3.42
  * Fixed memory leak (Thanks DaveM)
  * Add undef_str attribute
  * Tested against perl-5.28.0
  * Move from DynaLoader to XSLoader
  * Tested on Synology DSM
* Thu Mar 22 2018 pmonrealgonzalez@suse.com
- updated to 1.35
  see /usr/share/doc/packages/perl-Text-CSV_XS/ChangeLog
  1.35   - 2018-03-21, H.Merijn Brand
  * Remove META.yml from MANIFEST.skip
  * Use UNIVERSAL::isa to protect against unblessed references
  * -Wformat warning (RT#123729)
  * Make detect_bom result available
  * It's 2018
  * Add csv (out => \"skip") - suppress output deliberately
  * Allow sub as top-level filter
  * Tested against Test2::Harness-0.001062 (yath test)
  * Tested against perl-5.27.10
* Sun Dec 10 2017 coolo@suse.com
- updated to 1.34
  see /usr/share/doc/packages/perl-Text-CSV_XS/ChangeLog
  1.34	- 2017-11-05, H.Merijn Brand
  * Bad arg for formula (like "craok") will now die with error 1500
  * Row report in formula reporting was off by 1
  * Add a prominent section about BOM handling
  * Make sheet label more portable (csv2xlsx)
  * Allow munge => \%%hash
  * Preserve first row in csv (set_column_names => 0)
  1.33	- 2017-10-19, H.Merijn Brand
  * Small additional fix for eol = 
 + BOM
  * Updated doc for example files
  * Add support for formula actions (issue 11)
  - csv2xls and csv2xlsx now warn by default
  * Reset file info on ->header call (RT#123320)
* Sun Oct  8 2017 coolo@suse.com
- updated to 1.32
  see /usr/share/doc/packages/perl-Text-CSV_XS/ChangeLog
  1.32	- 2017-09-15, H.Merijn Brand
  * Add keep_headers attribute to csv ()
  * Fix on_in when used in combination with key
  * Fail on invalid arguments to csv
  * Fix header method on EOL = CR (RT#122764)
  1.31	- 2017-06-13, H.Merijn Brand
  * Fix already decoded BOM in headers
  * New options in csv-check
  * Some perlcritic
  * "escape" is alias for "escape_char" for consistency.
  * Code cleanup and more tests (Devel::Cover)
  * Improve csv-check auto-sep-detection
  1.30	- 2017-06-08, H.Merijn Brand
  * Add csv (..., out => ...) syntax examples (issue 7)
  * Disable escape_null for undefined escape_char
  * Fix ->say for bound columns (RT#121576)
  * Update to Devel::PPPort 3.36
  * Tested under 5.26.0 and 5.27.0
  * Doc changes and additions
  1.29	- 2017-04-25, H.Merijn Brand
  * More docs for bind_colmns (RT#121350)
  * New attribute "strict" (also addresses RT#121350)
  1.28	- 2017-03-22, H.Merijn Brand
  * Fix length problem with bound empty fields and UTF-8 (RT#120655)
  1.27	- 2017-03-02, H.Merijn Brand
  * Remove unneeded done_testing (Paul Howarth)
  * Attribute sep/sep_char is not allowed to be undefined
  * Increased test coverage: added errors 1008 and 1014
  * Default for escape_null in csv () is now false
  * It's 2017
  * New error code for illegal argument(s)/parameter(s) (RT#119827)
  * Fix tests for perl without dot in @INC
  * Fix crlf issue for csv () on Windows (RT#120466)
  1.26	- 2016-11-29, H.Merijn Brand
  * Disable some Unicode related tests for unhealthy $PERL_UNICODE
    (RT#117856)
  * is_missing (0) on empty line returns 1 for keep_meta_info = true
    (issue 27 on github)
  1.25	- 2016-08-28, H.Merijn Brand
  * Allow lc, uc, and coderef for csv () headers attribute
  * Document for eof when the last line has an error (RT#115954)
  * Allow csv () to call header () with all supported arguments
  * Add some docs for bind_columns
  1.24	- 2016-07-09, H.Merijn Brand
  * Fix typo in docs example code (issue#4, joevak)
  * Set auto-wrap on for csv2xls with embedded newlines
  * Add examples/csv2xlsx, the MSExcel-2007+ version of csv2xls
    Includes new feature to merge multiple CSV's into a single xlsx
  * Slight modification in examples
  * Fix parse error in complex option combo (RT#115953)
  - requires perl-5.6.2 or newer
  1.23	- 2016-03-25, H.Merijn Brand
  * Skip unsupported encodings
  * Reorganize Unicode section and mention layers (Dan Book)
  * Amend some UTF-8 tests for PERL_UNICODE settings
  * Fix crash on error in parsing with bound columns (RT#113279)
  * Add predefined filters (not_blank, not_empty, filled)
  1.22	- 2016-02-23, H.Merijn Brand
  * Small doc updates regarding blank_is_undef
  * Precedence error in doc
  * Add new method header
  1.21	- 2016-01-06, H.Merijn Brand
  * Add confusion option to rewrite example
  * Alias %%_ to row in hashref mode for csv function attributes
    on_in and before_out
  * Examples now use defined-or and thus require perl-5.10 or up
  * Fix
  ending with allow_loose_escapes (reported by Bas Bloemsaat)
  * It's 2016
  * Clarify $csv->csv (...) documentation (RT#110941)
  1.20	- 2015-10-09, H.Merijn Brand
  * Use "say" in synopsis
  * Remove needless special characters in doc section
  * Change doc =item attributes for new to =head for index
  * Add known_attributes function/method
  * Add contributor notes
  * Allow undef as value for aliased attributes
  1.19	- 2015-06-17, H.Merijn Brand
  * Guard tests against $PERL_UNICODE
  * Numeric options were sometimes interpreted as boolean
  * Safer meta_info use
  1.18	- 2015-05-22, H.Merijn Brand
  * Add quote_empty attribute
  * Add database NULL documentation
  * Inherit csv attributes in csv () when called in void context
  * micro-optimisation for combine/print (empty fields will be faster)
  1.17	- 2015-04-24, H.Merijn Brand
  * Enable overruling $csv in csv ()
  * Allow encoding to be shortened to enc in csv ()
  * Allow filter to alter content
  * Add say (print with default eol => $\)
  * Allow MS sep=; on first line (RT#100304)
  1.16	- 2015-03-02, H.Merijn Brand
  * filter made more useful (access to other fields)
  1.15	- 2015-02-11, H.Merijn Brand
  * Remove perl recommendation from META as it breaks cpan clients
  1.14	- 2015-02-02, H.Merijn Brand
  * Move to github
  * Add csv (filter => {});
  * Change csv ()'s void context behavior
  1.13	- 2015-01-03, H.Merijn Brand
  * Simplify code path for old perl
  * Fix quote_binary (#RT100676)
  * Fix csv () for hashrefs with aliased headers
  * Update copyright to 2015
  1.12	- 2014-11-01, H.Merijn Brand
  * Add field number to error_diag
  * Fixed non-IO parsing multi-byte EOL
  * Fixed a possible missed multi-byte EOL
  * Allow hashref for csv ()'s headers attribute
  * Allow encoding on all output handles in csv ()
  * Include doc changes as ticketed in the Text::CSV queue
  * Fix parallel testing issue
  * Allow csv as method call (not using the object)
  * Rename quote_null to escape_null
  * Give meaning to keep_meta_info on output (RT#99941)
  1.11	- 2014-08-16, H.Merijn Brand
  * Fixed eof (RT#97742)
  * Check for attribute conflicts early
  * csv (in => [..]) now defaults to *STDOUT for out
  * Support for multi-byte quote_char
  * New attribute "key" for csv ()
  1.10	- 2014-08-04, H.Merijn Brand
  * Support for scalar ref in out: csv (out => \(my $x = ""), ...)
  * Support for multi-byte sep_char
  * Simplified the cache coding
  1.09	- 2014-06-09, H.Merijn Brand
  * Missed defined-or need in csv2xls (RT#95787)
  1.08	- 2014-05-17, H.Merijn Brand
  * Documentation updates
  * Allow disjointed CSV cell fragment lists
  1.07	- 2014-04-28, H.Merijn Brand
  * Allow ref to scalar for csv (in => ...)
  * Allow CODE ref to in attribute
  * Allow * in fragment cellspec's bottom-right cell
  1.06	- 2014-04-20, H.Merijn Brand
  * Fix possible fail in tests on Windows (Thanks Mithaldu for explaing)
  * Only close file handles in csv () for files
  * new callbacks for csv ()
* Mon Mar 17 2014 coolo@suse.com
- updated to 1.05
  * Allow case insensitive attributes and attribute aliases
    (quote_always = always_quote)
  * Enhanced the csv () function (diagnostics)
  * Start callbacks support
  * Minor doc fixes
  * Make subclassing safer
* Mon Feb 24 2014 coolo@suse.com
- updated to 1.04
  * get_columnd () with no argument now returns the empty list
    instead of undef when no columns defined
  * fragments (rcf7111) now also support AoH (was AoA only)
  * Error code conflict for fragments resolved to 2013
  * New function "csv" (not a method)
  * Update copyright to 2014
  * Implement RCF7111
* Mon Nov 25 2013 coolo@suse.com
- updated to 1.02
  * Add example for reading only a single column
  * Don't store NULL in _ERROR_INPUT (RT#86217/Clone)
  * Prevent double-decode in csv-check
  * Add decode_utf8 attribute (default is true)
* Sat Jul 27 2013 coolo@suse.com
- updated to 1.01
  * Cache not re-read on getline_all (RT#86155)
  * Fix automatic UTF-8 in getline/parse for SV's with \0
  * Documents return value of bind_columns without arguments
  * Fix automatic UTF-8 in getline/parse
  * Clarify eol documentation
  * Move error_input to XS
* Mon Jun  3 2013 coolo@suse.com
- updated to 0.97
  * Regain the speed from 0.91 (buffer back to 1k)
  * Minor cleanup in XS code
  * Add diag_verbose attribute
  * No need to require Test::Harness if unused (RT#82693)
  * parse ("") should return one empty field, not undef
  * Now that we know the record number, show it in auto_diag
  * Introduce allow_unquoted_escape as workaround for RT#81295
  * Update copyright to 2013
  * Introduce print_hr () for RT#76143
  * Dropped plans to support EBCDIC
  * Guard against beta releases of Encode (Xavier Guimard - RT#81499)
  * Fix sv_cache init global-buffer-overflow (Reini Urban - RT#81469)
  * Tested with perl compiled with clang (also to verify RT#81469)
  * Fix memory leak reported in RT#81539 (Fix by Tony Cook)
  * Skip Encode related tests on too old Encode
  * Force old(er) tar format (ustar) - assumes GNU tar on release box
  * Allow bind_columns () for print ()
  * Increase buffer size for print to 64k
  * Fix RT#80680 - Buffer break halfway UTF8 + tests
  * Prevent test-failures for long doubles on weird architectures
  * More utf-8 tests for te change of 0.90
  * Update test case now 5.005 is not supported anymore
  * Rip out the tell/seek introduced in 0.90
  * Drop 5.005 support (5.6.1 is now minimum)
  * Introduce record_number
  * Try harder to get the complete input parsed for the current record
    when hitting errors on parsing seekable IO (only works in 5.14.0 and up)
  * Tested with perl 5.6.1 .. 5.17.0 (99 versions of perl) on Linux, HP-UX,
    AIX, and Windows
  * SvSETMAGIC was missing for tied variables causing weird actions at a
    distance, e.g. in printf (Thanks TonyC for finding this)
  * UTF8 flag was not always reset when using bound variables (TonyC)
  * Fix for $/ in 0.86 broke parsing fields that contain excessive $/'s
* Sun Mar 11 2012 coolo@suse.com
- updated to 0.87
  * Extra check on utf8 output (RT#74330)
  * examples/csvdiff now recognizes numerically sorted CSV files
  * Document example comparing getline_hr vs bind_columns + getline
* Fri Feb 17 2012 coolo@suse.com
- updated to 0.86
  * Introduce quote_binary attribute
  * Update copyright to 2012
  * Versions
  * Fixed a utf8::decode on undef (found by perl-5.15.7)
  * Fixed localized $/ interference with other handles (RT#74216)
* Tue Nov 29 2011 coolo@suse.com
- update to 0.85
  * NAME / DISTNAME in Makefile.PL
  * More cross-checks for META data
  * Fix spurious auto_diag warning (RT#69673)
  * Tested with 50 versions of perl, including 1.15.1
* Mon May 16 2011 coolo@opensuse.org
- updated to 0.82
  * Doc fix (RT#66905, Peter Newman)
  * Documentation overhaul (pod links)
* Thu Mar 31 2011 coolo@novell.com
- update to 0.81
  * Add is_missing ()
  * Doc overhaul
  * Fix Build on OpenVMS (RT#65654, Martin P.J. Zinser)
  * Fix SetDiag () leak (RT#66453, Sven Sch366ling)
  * Implement getline_all () and getaline_hr_all ()
  * Fixed another parsing for eol = \r (RT#61525)
  * Use correct type for STRLEN (HP-UX/PA-RISC/32)
  * More code coverage
  * EOF unreliable when line-end missing at eof
  * Internals now use warn () instead of (void)fprintf (stderr, ...)
    Now the test in t/80_diag also passes on Windows
  * Better parsing for eol = \r and set as such (RT#61525)
  * Workaround for AIX cpp bug (RT#62388, Jan Dubois)
  * Spelling fixes
  * Real eol support for parsing streams (beyond \n, \r and \r\n)
  * Clarify doc for always_quote to not quote undef fields
  * Clarify UTF8 process for print () and combine ()
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Wed Jun  2 2010 chris@computersalat.de
- update to 0.73
  * Improve date conversion in examples/csv2xls
    new option -D allows column selection for date conversions
  * Tested under perl-5.12.0 (and 21 other versions of perl)
  * Added a note about EBCDIC data files
  * Test suite is now safe for parallel test (prove --shuffle -j6)
- 2010-03-16 0.72 - H.Merijn Brand   <h.m.brand@xs4all.nl>
  * Introduce quote_null attribute (RT#55200)
  * examples/csv-check can be used for Text::CSV_PP
  * examples/csv-check more options for sep_, escape_ and quote_char
  * examples/csv2xls more options for sep_, escape_ and quote_char
  * examples/csv2xls added auto_diag and verbosity
  * Dropped YAML spec to 1.0
- 2010-02-15 0.71 - H.Merijn Brand   <h.m.brand@xs4all.nl>
  * Upped copyright to 2010
  * Prevent double encoding: make Text::CSV_XS streams behave just
    like perl would (thanks ikegami for the test cases)
  * Text::CSV_XS->error_diag () in void context now warns instead of
    doing nothing
  * auto_diag also used for new () itself
- fix deps, cleanup spec
* Sat Dec 12 2009 chris@computersalat.de
- update 0.70
  * Add quote_space attribute
  * Forbid \r and \n in sep_char, quote_char, and escape_char
  * 0.69 - H.Merijn Brand   <h.m.brand@xs4all.nl>
  * Missing end quotes in error code docs
  * examples/csv-check now shows detected eol
  * Auto detection of eol => "\r" in streams
  * Optimized caching. All cache changes now in XS
  * 0.68 - H.Merijn Brand   <h.m.brand@xs4all.nl>
  * Attribute auto_diag now localizes to +1 if autodie is active
  * Output name generation in csv2xls (RT#48954)
  * Added csvdiff to examples/
  * Reordered docs. Rewrote SYNOPSIS to be more like a real-world
    code example
- cleanup spec
  * define cpan_name
  * sort tags
  * fix build-/deps
  * added Authors
- added perl-macros
  * perl_gen_filelist
* Mon Aug 10 2009 coolo@novell.com
- update 0.67
  * Fix empty_diag typo for attribute handler
  * Fix AUTOMATED_TESTING erroneous skip
  * Reordered examples in doc to show best method first
  * Fail if first arg to new () is not a hash ref
  * Implement empty_is_undef on request of Evan Carroll
  * error_diag () uses warn () in void context instead of STDERR
  * Add auto_diag attribute (still under construction)
  * Initial known errors can now be checked on number (1002)
  * Added -u option to examples/csv-check to validate utf-8 encoding
  * All error_diag () returns should now be dual-var (both numeric
  ... see Changelog for many more fixes
* Mon Apr 14 2008 ug@suse.de
- version 0.41
- error_diag () subclassable
- typo in bind_columns () docs
- examples/csv2xls now uses getline ()
- better test for getline in t/75_hashref.t (makamata)
- document return value of getline () with bind_columns ()
- add perl version prereq to META.yml
- Implemented getline_hr () and column_names () RT 34474
  (suggestions accepted from Mark Stosberg)
- Corrected misspelled variable names in XS
- Functions are now =head2 type doc entries (Mark Stosberg)
- Make SetDiag() available to the perl level, so errors can
  be centralized and consistent
- Integrate the non-XS errors into XS
- Add t/75_hashref.t
- Testcase for error 2023 (Michael P Randall)
- Completely refactored the XS part of parse/getline, which
  is now up to 6%% faster. YMMV
- Completed bind_columns. On straight fetches now up to three
  times as fast as normal fetches (both using getline ())
* Fri Apr  4 2008 ug@suse.de
- version to 0.37
- Fix leak / make meta info available to getline () + tests
- Updated ppport.h
- auto-load IO::Handle when needed
- Diagnostics for failed new ()
- New 'blank_is_undef' option
- Fixed allow_whitespace issue, revealed by blank_is_undef
- Fixed parse error that passed for q{1, "bar",2} with escape_char +
- Extended XS coverage
- Removed error 2033
- Text-CSV_XS now under git
- Added $csv->error_diag () to SYNOPSIS
- Added need for diag when new () fails to TODO
- Fixed a sneaked-in defined or in examples/csv2xls
- Plugged a 32byte memory leak in the cache code (valgrind++)
- Improved usage for examples/csv2xls (GetOpt::Long now does --help/-?)
- Extended examples/csv2xls to deal with Unicode (-u)
- Serious bug in Text::CSV_XS::NV () type setting, causing the
  resulting field to be truncated to IV
* Mon Jul 16 2007 ug@suse.de
- version to 0.29
  * Removed an unused 'use Data::Dumper'
  * Added $csv->eof () RT 27424
  * Two typo's in the doc's (Amsterdam.pm)
  * Modified examples/speed.pl to better show the diffs between versions
  * Cache attribute settings and regain speed of 0.23! anmd beyond
  Relative overall speeds (YMMV, use examples/speed.pl to check),
  the 1.0x versions are from Text::CSV_PP.
    0.23 0.25 0.26 0.27 0.28 0.29 1.00 1.02 1.05
    ==== ==== ==== ==== ==== ==== ==== ==== ====
    combine   1   62   61   61   60   58  100   14   14   14
    combine  10   41   41   41   42   42  100    6    6    6
    combine 100   35   35   36   36   36  100    5    5    5
    parse     1  100   92   87   90   81   96   19   19   17
    parse    10   95  100   86   97   94   94   15   16   14
    parse   100   90   95   84   94   92  100   16   16   14
    print    io   93   89   91   91   95  100    0    0    6
    getline  io   90   92   84   87   89  100    0    0   13
  - --- ---- ---- ---- ---- ---- ---- ---- ----
    average       75   75   71   74   73   98    9    9   11
  * Removed prototypes
  * Added a SPECIFICATION section to the pod
  * Safe caching of eol, and a warning in the docs
  * Rewrote t/20_file.t do do actual file IO instead of IO_Scalar fake
  * Small optimilisation for parse (juerd)
  * Added make target test_speed
  * Merged the items from CAVEAT to SPECIFICATION
  * Updated the TODO and Release Plan sections
  * Speed up internals by using references instead of copies (juerd)
  * Reworked error_input, which also had an undetected internal error
  * Added IO tests for lexical IO handles and perlio IO to/from scalars
  * IMPORTANT CHANGE: new () returns undef if it gets unsupported
  attributes. Until now, new ({ esc_char => "\\" }) was just
  silently ignored. Rejecting it and failing is better than
  continuing with false assumptions.
  * Added allow_loose_quotes  (see doc)
  * Added t/65_allow.t
  * Added allow_loose_escapes (see doc) RT 15076
  * More code cleanup in XS
  * Added allow_whitespace    (see doc)
  * checked with perlcritic (still works under 5.00504)
  so 3-arg open cannot be used (except in the docs)
  * 3-arg open in docs too
  * Added a lot to the TODO list
  * Some more info on using escape character (jZed)
  * Mention Text::CSV_PP in README
  * Added t/45_eol.t, eol tests
  * Added a section about embedded newlines in the pod
  * Allow \r as eol ($/) for parsing
  * More docs for eol
  * More eol = \r fixes, tfrayner's test case added to t/45_eol.t
  * Add $csv->allow_undef (1) suggestion in TODO
  Still have to find the best spot to document
  the difference between empty string and undef
  * Spell-checked the pod and fixed some typo's
  * Added t/70_rt.t
  - Regression         for RT 24386: \t doesn't work (WFM)
  - Regression and fix for RT 21530: getline () return at eof
    This one still passes under perl 5.00504
  - Regression         for RT 18703: Fails to use quote_char of '~'
  * Added t/55_combi.t for most combinations of always_quote,
  sep_char, quote_char, and escape_char
  * Added docs about sep_char not allowed to be either quote_char
  or escape_char
  * Both combine () and parse () now return FALSE id sep_char is
  equal to either quote_char or escape_char. Done in XS, as it
  was a slowdown of 10%% when done in perl.
  * Merijn got the maintainership
- code reformat and code cleanup
- renamed internal (Encode, Decode) to (Combine, Parse) to
  prevent misinterpretation with upcoming Unicode changes
  and possible name clashes
- added pod check (and fixed pod)
- added pod coverage and small additions to the pod.
  More to do in this area
- renamed test to fixate the sequence
- Added t/50_utf8.t
- tests now use Test::More
  . Makefile.PL requires Test::More
- checked proclaimed version compatibility
  . 5.9.x-64int     works @31159
  . 5.8.x-64int-dor works @31162
  . 5.8.0-dor       works
  . 5.6.2           works
  . 5.005.04        works
  . 5.004.05        fails
- 5.005 is now prerequisite
- Added missing info in docs for new ()
- Added meta_info () method and docs
- Added keep_meta_info in new ()
- Added t/15_flags.t
- Added test_cover make target
- Added test for error_input ()
- Added tests for fields () and meta_info () before parse ()
- Added tests for ->types () as method
- Added tests for deleting types (coverage now over 99%%)
- Added is_quoted (), is_binary () and tests
- Added COPYRIGHT section to pod
- Added the parse example from the pod to test.pl
- Added accessor methods for internals: quote_char () et all
- Added tests for the new accessor methods
- Added always_quote to the missing places in the doc and in new ()
- Changed the tests to use the accessors instead of the hash keys
  except for the ->{types} and ->{_types}
- Moved test.pl to examples/speed.pl
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Fri Jul 18 2003 nashif@suse.de
- use DESTDIR
- fixed filelist
* Tue Jul  1 2003 ro@suse.de
- use perl_process_packlist macro
* Fri Jun 13 2003 nashif@suse.de
- Fixed file list
* Mon Jul  8 2002 nashif@suse.de
- use mandir macro
* Tue Dec 11 2001 nashif@suse.de
- Update to version 0.23
* Wed Mar  7 2001 nashif@suse.de
- Update to version 0.22
* Wed Nov  8 2000 nashif@suse.de
- removed buiuld root path from packlist
* Tue Nov  7 2000 nashif@suse.de
- Changed to long package name
* Wed Oct 11 2000 nashif@suse.de
- Fixed man path
* Thu Aug 24 2000 nashif@suse.de
- Initial Release (0.20)
